@@ -102,6 +102,9 @@ void extracthalf(const char *debar, const char *directory,
   char *cur;
   struct ar_hdr arh;
   int readfromfd, oldformat, header_done, adminmember, c;
+#if defined(__GLIBC__) && (__GLIBC__ == 2) && (__GLIBC_MINOR__ > 0)
+  fpos_t fpos;
+#endif
   
   ar= fopen(debar,"r"); if (!ar) ohshite(_("failed to read archive `%.255s'"),debar);
   if (fstat(fileno(ar),&stab)) ohshite(_("failed to fstat archive"));
@@ -209,7 +212,13 @@ void extracthalf(const char *debar, const char *directory,
 
   }
 
+#if defined(__GLIBC__) && (__GLIBC__ == 2) && (__GLIBC_MINOR__ > 0)
+  if(fgetpos(ar, &fpos)) ohshit(_("fgetpos failed"));
+#endif
   fflush(ar);
+#if defined(__GLIBC__) && (__GLIBC__ == 2) && (__GLIBC_MINOR__ > 0)
+  if(fsetpos(ar, &fpos)) ohshit(_("fsetpos failed"));
+#endif
   if (oldformat) {
     if (admininfo) {
       m_pipe(p1);
