@@ -444,7 +444,11 @@ int tarobject(struct TarInfo *ti) {
     if (symlink(ti->LinkName,fnamenewvb.buf))
       ohshite(_("error creating symbolic link `%.255s'"),ti->Name);
     debug(dbg_eachfiledetail,"tarobject SymbolicLink creating");
+#ifdef HAVE_LCHOWN
+    if (lchown(fnamenewvb.buf,ti->UserID,ti->GroupID))
+#else
     if (chown(fnamenewvb.buf,ti->UserID,ti->GroupID))
+#endif
       ohshite(_("error setting ownership of symlink `%.255s'"),ti->Name);
     break;
   case Directory:
@@ -500,7 +504,11 @@ int tarobject(struct TarInfo *ti) {
       symlinkfn.used= r; varbufaddc(&symlinkfn,0);
       if (symlink(symlinkfn.buf,fnametmpvb.buf))
         ohshite(_("unable to make backup symlink for `%.255s'"),ti->Name);
+#ifdef HAVE_LCHOWN
+      if (lchown(fnametmpvb.buf,stab.st_uid,stab.st_gid))
+#else
       if (chown(fnametmpvb.buf,stab.st_uid,stab.st_gid))
+#endif
         ohshite(_("unable to chown backup symlink for `%.255s'"),ti->Name);
     } else {
       debug(dbg_eachfiledetail,"tarobject nondirectory, `link' backup");
