@@ -58,7 +58,7 @@ void process_archive(const char *filename) {
   static int p1[2];
   static char cidirtmpnambuf[L_tmpnam+100];
   static char *cidirbuf=0, *reasmbuf=0;
-  static struct fileinlist *newconffiles;
+  static struct fileinlist *newconffiles, *newfileslist;
   static enum pkgstatus oldversionstatus;
   static struct varbuf infofnvb, fnvb, depprobwhy;
   static struct tarcontext tc;
@@ -69,7 +69,7 @@ void process_archive(const char *filename) {
   char *cidir, *cidirrest, *p;
   char pfilenamebuf[35], conffilenamebuf[MAXCONFFILENAME];
   const char *pfilename, *newinfofilename;
-  struct fileinlist *newconff, **newconffileslastp, *newfileslist;
+  struct fileinlist *newconff, **newconffileslastp;
   struct fileinlist *cfile;
   struct reversefilelistiter rlistit;
   struct conffile *searchconff, **iconffileslastp, *newiconff;
