@@ -11,20 +11,44 @@ $maxsubsts=50;
 
 $progname= $0; $progname= $& if $progname =~ m,[^/]+$,;
 
+$getlogin = getlogin();
+if(!defined($getlogin)) {
+	open(SAVEIN, "<&STDIN");
+	close(STDIN);
+	open(STDIN, "<&STDERR");
+
+	$getlogin = getlogin();
+
+	close(STDIN);
+	open(STDIN, "<&SAVEIN");
+	close(SAVEIN);
+}
+if(!defined($getlogin)) {
+	open(SAVEIN, "<&STDIN");
+	close(STDIN);
+	open(STDIN, "<&STDOUT");
+
+	$getlogin = getlogin();
+
+	close(STDIN);
+	open(STDIN, "<&SAVEIN");
+	close(SAVEIN);
+}
+
 if (defined ($ENV{'LOGNAME'})) {
-    if (!defined (getlogin ())) { 
+    if (!defined ($getlogin)) { 
 	warn (sprintf ('no utmp entry available, using value of LOGNAME ("%s")', $ENV{'LOGNAME'})); 
     } else {
-	if (getlogin () ne $ENV{'LOGNAME'}) { 
+	if ($getlogin ne $ENV{'LOGNAME'}) { 
 	    warn (sprintf ('utmp entry ("%s") does not match value of LOGNAME ("%s"); using "%s"',
-			   getlogin(), $ENV{'LOGNAME'}, $ENV{'LOGNAME'}));
+			   $getlogin, $ENV{'LOGNAME'}, $ENV{'LOGNAME'}));
 	}
     }
     @fowner = getpwnam ($ENV{'LOGNAME'});
     if (! @fowner) { die (sprintf ('unable to get login information for username "%s"', $ENV{'LOGNAME'})); }
-} elsif (defined (getlogin ())) {
-    @fowner = getpwnam (getlogin ());
-    if (! @fowner) { die (sprintf ('unable to get login information for username "%s"', getlogin ())); }
+} elsif (defined ($getlogin)) {
+    @fowner = getpwnam ($getlogin);
+    if (! @fowner) { die (sprintf ('unable to get login information for username "%s"', $getlogin)); }
 } else {
     warn (sprintf ('no utmp entry available and LOGNAME not defined; using uid of process (%d)', $<));
     @fowner = getpwuid ($<);
@@ -39,7 +63,7 @@ sub capit {
 
 sub findarch {
     $arch=`dpkg --print-architecture`;
-    $? && &subprocerr("dpkg --print-archictecture");
+    $? && &subprocerr("dpkg --print-architecture");
     $arch =~ s/\n$//;
     $substvar{'Arch'}= $arch;
 }
@@ -66,7 +90,7 @@ sub substvars {
 sub outputclose {
     my ($dosubstvars) = @_;
     for $f (keys %f) { $substvar{"F:$f"}= $f{$f}; }
-    if (length($varlistfile)) {
+    if (length($varlistfile) and $dosubstvars) {
         $varlistfile="./$varlistfile" if $varlistfile =~ m/\s/;
         if (open(SV,"< $varlistfile")) {
             while (<SV>) {
@@ -77,7 +101,7 @@ sub outputclose {
                 $substvar{$1}= $';
             }
             close(SV);
-        } elsif ($! !~ m/no such file or directory/i) {
+        } elsif ($! != ENOENT ) {
             &error("unable to open substvars file $varlistfile: $!");
         }
     }
