@@ -13,7 +13,9 @@ version 2 or later for copying conditions.  There is NO warranty.
 
 Usage: dpkg-buildpackage [options]
 Options: -r<gain-root-command>
-         -p<pgp-command>
+         -p<sign-command>
+         -sgpg         the sign-command is called like GPG
+         -spgp         the sign-command is called like PGP 
          -us           unsigned source
          -uc           unsigned changes
          -a<arch>      architecture field of the changes _file_name_
@@ -25,13 +27,25 @@ Options: -r<gain-root-command>
          -si (default) src includes orig for rev. 0 or 1    } genchanges
          -sa           uploaded src always includes orig    }
          -sd           uploaded src is diff and .dsc only   }
+         -nc           do not clean source tree (implies -b)
          -tc           clean source tree when finished
          -h            print this message
 END
 }
 
 rootcommand=''
-pgpcommand=pgp
+signcommand=pgp # Default command for signing
+warnpgp='no'	# Display a warning to encourage switching to gpg?
+if [ ! -e $HOME/.gnupg/secring.gpg ] ; then
+	warnpgp=yes
+fi
+if [ -e $HOME/.gnupg/secring.gpg -a ! -e $HOME/.pgp/secring.pgp ] ; then
+	signcommand=gpg
+fi
+if [ -e $HOME/.pgp/secring.pgp -a ! -e $HOME/.gnupg/secring.gpg ] ; then
+	signcommand=pgp
+fi
+signinterface=$signcommand
 signsource='withecho signfile'
 signchanges='withecho signfile'
 cleansource=false
@@ -41,6 +55,7 @@ version=''
 since=''
 maint=''
 desc=''
+noclean=false
 
 while [ $# != 0 ]
 do
@@ -48,14 +63,17 @@ do
 	case "$1" in
 	-h)	usageversion; exit 0 ;;
 	-r*)	rootcommand="$value" ;;
-	-p*)	pgpcommand="$value" ;;
-	-us)	signsource=: ;;
-	-uc)	signchanges=: ;;
+	-p*)	signcommand="$value"; warnpgp='' ;;
+	-sgpg)  signinterface=gpg ;;
+	-spgp)  signinterface=pgp ;;
+	-us)	signsource=: ; warnpgp='' ;;
+	-uc)	signchanges=: ; warnpgp='' ;;
 	-a*)    opt_a=1; arch="$value" ;;
 	-si)	sourcestyle=-si ;;
 	-sa)	sourcestyle=-sa ;;
 	-sd)	sourcestyle=-sd ;;
 	-tc)	cleansource=true ;;
+	-nc)	noclean=true; binaryonly=-b ;;
 	-b)	binaryonly=-b ;;
 	-B)	binaryonly=-B; binarytarget=binary-arch ;;
 	-v*)	since="$value" ;;
@@ -67,12 +85,20 @@ do
 	shift
 done
 
+if test "X$warnpgp" = "Xyes" ; then
+  echo >&2 <<EOWARN
+The Debian project will switch to using GPG (the GNU Privacy Guard) instead
+of PGP for signing packages. You might want to make preparations. Check out
+the gnupg and debian-keyring packages.
+EOWARN
+fi
+
 mustsetvar () {
 	if [ "x$2" = x ]; then
-		echo >&2 "$progname: unable to determine $3"
+		echo >&2 "$progname: unable to determine $3" ; \
 		exit 1
 	else
-		echo "$progname: $3 is $2"
+		echo "$progname: $3 is $2" ; \
 		eval "$1=\"\$2\""
 	fi
 }
@@ -82,7 +108,7 @@ dirn="`basename \"$curd\"`"
 mustsetvar package "`dpkg-parsechangelog | sed -n 's/^Source: //p'`" "source package"
 mustsetvar version "`dpkg-parsechangelog | sed -n 's/^Version: //p'`" "source version"
 if [ -n "$maint" ]; then maintainer="$maint"; 
-else mustsetvar maintainer "`dpkg-parsechangelog | sed -n 's/^Maintainer: //p'`" "source version"; fi
+else mustsetvar maintainer "`dpkg-parsechangelog | sed -n 's/^Maintainer: //p'`" "source maintainer"; fi
 test "${opt_a}" \
 	|| mustsetvar arch "`dpkg --print-architecture`" "build architecture"
 
@@ -91,7 +117,17 @@ pv="${package}_${sversion}"
 pva="${package}_${sversion}${arch:+_${arch}}"
 
 signfile () {
-	$pgpcommand -u "$maintainer" +clearsig=on -fast <"../$1" >"../$1.asc"
+	if test $signinterface = gpg ; then
+		# --textmode doesn't seem to work; we use perl to filter ^M;
+		# this doesn't affect the actual signature.
+		(cat "../$1" ; echo "") | \
+		$signcommand --local-user "$maintainer" --clearsign --armor \
+			--textmode --output - - | \
+			perl -n -p -e 's/\r$//' > "../$1.asc" 
+	else
+		$signcommand -u "$maintainer" +clearsig=on -fast <"../$1" \
+			>"../$1.asc"
+	fi
 	echo
 	mv -- "../$1.asc" "../$1"
 }
@@ -106,7 +142,9 @@ if [ -n "$maint"	]; then set -- "$@" "-m$maint"		; fi
 if [ -n "$since"	]; then set -- "$@" "-v$since"		; fi
 if [ -n "$desc"		]; then set -- "$@" "-C$desc"		; fi
 
-withecho $rootcommand debian/rules clean
+if [ x$noclean != xtrue ]; then
+	withecho $rootcommand debian/rules clean
+fi
 if [ x$binaryonly = x ]; then
 	cd ..; withecho dpkg-source -b "$dirn"; cd "$dirn"
 fi
