@@ -101,7 +101,7 @@ while (@ARGV) {
 $fileslistfile="./$fileslistfile" if $fileslistfile =~ m/^\s/;
 open(FL,"< $fileslistfile") || &syserr("cannot read files list file");
 while(<FL>) {
-    if (m/^(([-+.0-9a-z]+)_([^_]+)_(\w+)\.deb) (\S+) (\S+)$/) {
+    if (m/^(([-+.0-9a-z]+)_([^_]+)_([-\w]+)\.deb) (\S+) (\S+)$/) {
         defined($p2f{"$2 $4"}) &&
             &warn("duplicate files list entry for package $2 (line $.)");
 	$f2p{$1}= $2;
@@ -138,7 +138,8 @@ for $_ (keys %fi) {
 #print STDERR "P key >$_< value >$v<\n";
 	$i=$1; $p=$fi{"C$i Package"}; $a=$fi{"C$i Architecture"};
 	if (!defined($p2f{$p})) {
-	    if (!$archspecific || $a eq $substvar{'Arch'}) {
+	    if ($a eq 'any' || ($a eq 'all' && !$archspecific) ||
+		grep($_ eq $substvar{'Arch'}, split(/\s+/, $a))) {
 		&error("package $p in control file but not in files list");
 	    }
 	} else {
@@ -154,8 +155,12 @@ for $_ (keys %fi) {
 	    } elsif (s/^X[BS]*C[BS]*-//i) {
 		$f{$_}= $v;
 	    } elsif (m/^Architecture$/) {
-		$v= $arch if $v eq 'any';
-		push(@archvalues,$v) unless $archadded{$v}++;
+		if ($v eq 'any' || grep($_ eq $arch, split(/\s+/, $v))) {
+		    $v= $arch;
+		} elsif ($v ne 'all') {
+		    $v= '';
+		}
+		push(@archvalues,$v) unless !$v || $archadded{$v}++;
 	    } elsif (m/^(Package|Essential|Pre-Depends|Depends|Provides)$/ ||
 		     m/^(Recommends|Suggests|Optional|Conflicts|Replaces)$/ ||
 		     m/^X[CS]+-/i) {
