@@ -219,11 +219,11 @@ eof(OLD) || &ulquit("$name: read $infodir/dir: $!\n");
 close(OLD) || &ulquit("$name: close $infodir/dir after read: $!\n");
 while ($work[$#work] !~ m/\S/) { $#work--; }
 
-do {
-    last if !@work;
-    $_= shift(@work);
+while (@work) {
+	$_=shift(@work);
     push(@head,$_);
-} until (m/^\*\s*Menu:/i);
+	last if (m/^\*\s*Menu:/i);
+}
 
 if (!$remove) {
 
